package info.aspirecn.cloud.yysj.cloudyysjagency.controller;

import info.aspirecn.cloud.yysj.cloudyysjagency.exceptions.SystemBusyException;
import info.aspirecn.cloud.yysj.cloudyysjagency.exceptions.TokenIsEmptyException;
import info.aspirecn.cloud.yysj.cloudyysjagency.service.YysjAgencyService;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

@RestController
@RequestMapping("/api/analysisQuery")
public class AnalysisController {

    @Autowired
    private YysjAgencyService yysjAgencyService;

    @ApiOperation(value = "账户信息", notes = "获取用户当日消费金额和账户余额。")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "userId", value = "用户ID", dataType = "string", required = true, paramType = "header")
    })
    @GetMapping("/accountInfo")
    public Object getAccountInfo(HttpServletRequest request, HttpServletResponse response) {
        String token = request.getHeader("token");
        if (StringUtils.isEmpty(token)) {
            throw new TokenIsEmptyException("请求头token为空");
        }
        Object object = yysjAgencyService.getAccountInfo(token, response);
        if (object == null) {
            throw new SystemBusyException("账户信息接口返回为空");
        }
        return object;
    }

    @ApiOperation(value = "产品消费信息", notes = "获取账户当月订购产品的消费及占比信息。")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "userId", value = "用户ID", dataType = "string", required = true, paramType = "header")
    })
    @GetMapping("/consumptionInfo")
    public Object getConsumptionInfo(HttpServletRequest request, HttpServletResponse response) {
        String token = request.getHeader("token");
        if (StringUtils.isEmpty(token)) {
            throw new TokenIsEmptyException("请求头token为空");
        }
        Object object = yysjAgencyService.getConsumptionInfo(token, response);
        if (object == null) {
            throw new SystemBusyException("产品消费信息接口返回为空");
        }
        return object;
    }

    @ApiOperation(value = "主订单统计信息", notes = "获取账户最新 15 天订单统计信息。")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "userId", value = "用户ID", dataType = "string", paramType = "header")
    })
    @GetMapping("/statisticsInfo")
    public Object getOrderStatistics(HttpServletRequest request, HttpServletResponse response) {
        String token = request.getHeader("token");
        if (StringUtils.isEmpty(token)) {
            throw new TokenIsEmptyException("请求头token为空");
        }
        Object object = yysjAgencyService.getOrderStatistics(token, response);
        if (object == null) {
            throw new SystemBusyException("主订单统计信息接口返回为空");
        }
        return object;
    }

    @ApiOperation(value = "总订单统计信息", notes = "获取指定日期内，总订单统计结果信息。")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "endTime", value = "结束时间", dataType = "string", required = true, paramType = "query"),
            @ApiImplicitParam(name = "startTime", value = "开始时间", dataType = "string", required = true, paramType = "query"),
            @ApiImplicitParam(name = "userId", value = "用户ID", dataType = "string", required = true, paramType = "header")
    })
    @GetMapping("/countStatisticsInfo")
    public Object getCountStatistics(@RequestParam(required = true) String startTime,
                                     @RequestParam(required = true) String endTime,
                                     HttpServletRequest request, HttpServletResponse response) {
        String token = request.getHeader("token");
        if (StringUtils.isEmpty(token)) {
            throw new TokenIsEmptyException("请求头token为空");
        }
        Object object = yysjAgencyService.getCountStatistics(startTime, endTime, token, response);
        if (object == null) {
            throw new SystemBusyException("总订单统计信息接口返回为空");
        }
        return object;

    }

    @ApiOperation(value = "异常效验统计信息", notes = "获取指定日期内，获取一致、不一致订单统计结果信息。")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "startTime", value = "开始时间", dataType = "string", required = true, paramType = "query"),
            @ApiImplicitParam(name = "endTime", value = "结束时间", dataType = "string", required = true, paramType = "query"),
            @ApiImplicitParam(name = "userId", value = "用户ID", dataType = "string", required = true, paramType = "header")
    })

    @GetMapping("/exceptionStatisticsInfo")
    public Object getErrorStatistics(@RequestParam(required = true) String startTime,
                                     @RequestParam(required = true) String endTime,
                                     HttpServletRequest request, HttpServletResponse response) {
        String token = request.getHeader("token");
        if (StringUtils.isEmpty(token)) {
            throw new TokenIsEmptyException("请求头token为空");
        }
        Object object = yysjAgencyService.getErrorStatistics(startTime, endTime, token, response);
        if (object == null) {
            throw new SystemBusyException("异常效验统计信息接口返回为空");
        }
        return object;
    }
}
