package info.aspirecn.cloud.yysj.cloudyysjagency.controller;

import info.aspirecn.cloud.yysj.cloudyysjagency.entity.request.remote.CarQueryParam;
import info.aspirecn.cloud.yysj.cloudyysjagency.exceptions.ParamaterException;
import info.aspirecn.cloud.yysj.cloudyysjagency.exceptions.SystemBusyException;
import info.aspirecn.cloud.yysj.cloudyysjagency.exceptions.TokenIsEmptyException;
import info.aspirecn.cloud.yysj.cloudyysjagency.service.YysjAgencyService;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

@RestController
@RequestMapping("/api/carQuery")
public class CarController {

    @Autowired
    private YysjAgencyService yysjAgencyService;

    @ApiOperation(value = "车辆列表", notes = "查询车辆信息列表")
    @PostMapping("/querycar")
    public Object queryCarList(@RequestBody CarQueryParam carQueryParam, HttpServletRequest request, HttpServletResponse response) {
        //判断请求头token是否为空
        String token = request.getHeader("token");
        if (StringUtils.isEmpty(token)) {
            throw new TokenIsEmptyException("请求头token为空");
        }
        Object object = yysjAgencyService.queryCarList(carQueryParam, token, response);
        if (object == null) {
            throw new SystemBusyException("车辆列表接口返回值为空");
        }
        return object;
    }
    /**
     * 车辆详情接口
     */
    @ApiOperation(value = "车辆详情", notes = "查询车辆详情")
    @GetMapping("/querycarinfo/{carId}")
    public Object queryCarInfo(@PathVariable(required = true) String carId, HttpServletRequest request, HttpServletResponse response) {
        //判断参数不为空
        if (StringUtils.isEmpty(carId)) {
            throw new ParamaterException("请求参数为空");
        }
        //判断请求头参数不为空
        String token = request.getHeader("token");
        if (StringUtils.isEmpty(token)) {
            throw new TokenIsEmptyException("请求头token为空");
        }
        Object object = yysjAgencyService.queryCarInfo(carId, token, response);
        if (object == null) {
            throw new SystemBusyException("车辆详情接口返回值为空");
        }
        return object;
    }
}
