package info.aspirecn.cloud.yysj.cloudyysjagency.controller;

import info.aspirecn.cloud.yysj.cloudyysjagency.exceptions.SystemBusyException;
import info.aspirecn.cloud.yysj.cloudyysjagency.exceptions.TokenIsEmptyException;
import info.aspirecn.cloud.yysj.cloudyysjagency.service.YysjAgencyService;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

@RestController
@RequestMapping("/api/orderQuery")
public class OrderController {

    @Autowired
    private YysjAgencyService yysjAgencyService;

    @GetMapping("/orderList")
    public Object getOrderList(@RequestParam(required = false,defaultValue = "") String orderId,
                                     @RequestParam(required = false,defaultValue = "") String startTime,
                                     @RequestParam(required = false,defaultValue = "") String endTime,
                                     @RequestParam(required = false, defaultValue = "1") Integer pageNum,
                                     @RequestParam(required = false, defaultValue = "10") Integer pageSize,
                                     HttpServletRequest request,
                                     HttpServletResponse response) {
        String token = request.getHeader("token");
        if (StringUtils.isEmpty(token)) {
            throw new TokenIsEmptyException("请求头token为空");
        }
        Object object = yysjAgencyService.getOrderList(orderId,startTime, endTime,pageNum,pageSize,token, response);
        if (object == null) {
            throw new SystemBusyException("主订单列表接口返回为空");
        }
        return object;
    }

    @ApiOperation(value = "主订单详情查询", notes = "查询主订单详情信息（子订单信息）。")
    @GetMapping("/order/{orderId}")
    public Object getOrderDetail(@PathVariable(required = true) String orderId,HttpServletRequest request,HttpServletResponse response) {
        String token = request.getHeader("token");
        if (StringUtils.isEmpty(token)) {
            throw new TokenIsEmptyException("请求头token为空");
        }
        Object object = yysjAgencyService.getOrderDetail(orderId,token, response);
        if (object == null) {
            throw new SystemBusyException("主订单详情查询接口返回为空");
        }
        return object;
    }
}
