package info.aspirecn.cloud.yysj.cloudyysjagency.controller;

import info.aspirecn.cloud.yysj.cloudyysjagency.entity.request.remote.*;
import info.aspirecn.cloud.yysj.cloudyysjagency.exceptions.SystemBusyException;
import info.aspirecn.cloud.yysj.cloudyysjagency.exceptions.TokenIsEmptyException;
import info.aspirecn.cloud.yysj.cloudyysjagency.service.YysjAgencyService;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

@RestController
@RequestMapping("/api/productConfig")
@Api(tags = "云验平台登录接口")
@ApiResponses({
        @ApiResponse(code = 200, message = "请求成功"),
        @ApiResponse(code = 400, message = "请求参数错误"),
        @ApiResponse(code = 401, message = "请求token无效"),
        @ApiResponse(code = 403, message = "请求token过期"),
        @ApiResponse(code = 404, message = "请求地址没有发现"),
        @ApiResponse(code = 500, message = "系统异常"),
})
public class ProductController {

    @Autowired
    private YysjAgencyService yysjAgencyService;


//    @ApiOperation(value = "新建产品接口", notes = "新建产品接口")
//    @PostMapping(value ="/saveProduce")
//    public Object saveProduce(@RequestBody Produce produce, HttpServletRequest request, HttpServletResponse response) {
//
//        String token = request.getHeader("token");
//        if (StringUtils.isEmpty(token)) {
//            throw new TokenIsEmptyException("请求头token为空");
//        }
//        Object object = yysjAgencyService.saveProduce(produce, token, response);
//        if (object == null) {
//            throw new SystemBusyException("新建产品接口返回为空");
//        }
//        return object;
//    }

    @ApiOperation(value = "查询产品列表接口", notes = "获取产品列表接口")
    @PostMapping("/productList")
    public Object productList(@RequestBody ProduceList produceList, HttpServletRequest request, HttpServletResponse response) {
        String token = request.getHeader("token");
        if (StringUtils.isEmpty(token)) {
            throw new TokenIsEmptyException("请求头token为空");
        }
        Object object = yysjAgencyService.productList(produceList, token, response);
        if (object == null) {
            throw new SystemBusyException("查询产品列表接口返回为空");
        }
        return object;
    }

    @ApiOperation(value = "订购产品接口", notes = "订购产品接口")
    @PostMapping(value = "/saveUserProduce")
    public Object saveUserProduce(@RequestBody UserProduce userProduce, HttpServletRequest request, HttpServletResponse response) {
        String token = request.getHeader("token");
        if (StringUtils.isEmpty(token)) {
            throw new TokenIsEmptyException("请求头token为空");
        }
        Object object = yysjAgencyService.saveUserProduce(userProduce, token, response);
        if (object == null) {
            throw new SystemBusyException("订购产品接口返回为空");
        }
        return object;
    }


    @ApiOperation(value = "取消订购产品接口", notes = "取消订购产品接口")
    @DeleteMapping(value = "/deleteUserProduce")
    public Object deleteUserProduce(@RequestParam(required = true) Integer produceId,
                                     @RequestParam(required = true) String produceName,
                                     HttpServletRequest request,
                                     HttpServletResponse response) {
        String token = request.getHeader("token");
        if (StringUtils.isEmpty(token)) {
            throw new TokenIsEmptyException("请求头token为空");
        }
        Object object = yysjAgencyService.deleteUserProduce(produceId,produceName, token, response);
        if (object == null) {
            throw new SystemBusyException("取消订购产品接口返回为空");
        }
        return object;

    }

    @ApiOperation(value = "获取订购产品数量接口", notes = "获取订购产品数量接口")
    @GetMapping("/getOrderProductCount")
    public Object getOrderProductCount(HttpServletRequest request, HttpServletResponse response) {
        String token = request.getHeader("token");
        if (StringUtils.isEmpty(token)) {
            throw new TokenIsEmptyException("请求头token为空");
        }
        Object object = yysjAgencyService.getOrderProductCount(token, response);
        if (object == null) {
            throw new SystemBusyException("获取订购产品数量接口返回为空");
        }
        return object;
    }


    @ApiOperation(value = "获取产品名称列表接口", notes = "获取产品名称列表接口")
    @GetMapping("/getProductNameList")
    public Object getProductNameList(HttpServletRequest request, HttpServletResponse response) {
        String token = request.getHeader("token");
        if (StringUtils.isEmpty(token)) {
            throw new TokenIsEmptyException("请求头token为空");
        }
        Object object = yysjAgencyService.getProductNameList(token, response);
        if (object == null) {
            throw new SystemBusyException("获取产品名称列表接口返回为空");
        }
        return object;
    }


}
