package info.aspirecn.cloud.yysj.cloudyysjagency.controller;

import info.aspirecn.cloud.yysj.cloudyysjagency.entity.request.remote.WaybillQueryParam;
import info.aspirecn.cloud.yysj.cloudyysjagency.exceptions.SystemBusyException;
import info.aspirecn.cloud.yysj.cloudyysjagency.exceptions.TokenIsEmptyException;
import info.aspirecn.cloud.yysj.cloudyysjagency.service.YysjAgencyService;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

@RestController
@RequestMapping("/api/waybillQuery")
public class WaybillController {

    @Autowired
    private YysjAgencyService yysjAgencyService;

    @ApiOperation(value = "运单列表", notes = "查询运单信息列表")
    @PostMapping("/querywaybill")
    public Object queryWaybillList(HttpServletResponse response,
                                    HttpServletRequest request,
                                    @RequestBody WaybillQueryParam waybillQueryParam) {
        String token = request.getHeader("token");
        if (StringUtils.isEmpty(token)) {
            throw new TokenIsEmptyException("请求头token为空");
        }
        Object object = yysjAgencyService.queryWaybillList(response, waybillQueryParam, token);
        if (object == null) {
            throw new SystemBusyException("运单列表接口返回为空");
        }
        return object;
    }

    @ApiOperation(value = "运单详情", notes = "查询运单详情")
    @GetMapping("/querywaybillinfo/{waybillId}")
    public Object querywaybillinfo(@PathVariable(required = true) String waybillId,
                                    HttpServletRequest request,
                                    HttpServletResponse response) {
        String token = request.getHeader("token");
        if (StringUtils.isEmpty(token)) {
            throw new TokenIsEmptyException("请求头token为空");
        }
        Object object = yysjAgencyService.querywaybillinfo(waybillId, token, response);
        if (object == null) {
            throw new SystemBusyException("运单详情接口返回为空");
        }
        return object;
    }
}
