package info.aspirecn.cloud.yysj.cloudyysjagency.controller.exception;

import info.aspirecn.cloud.yysj.cloudyysjagency.controller.ProductController;
import info.aspirecn.cloud.yysj.cloudyysjagency.entity.response.Result;
import info.aspirecn.cloud.yysj.cloudyysjagency.enums.ResultEnum;
import info.aspirecn.cloud.yysj.cloudyysjagency.exceptions.*;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.RestControllerAdvice;
import javax.servlet.http.HttpServletResponse;

@RestControllerAdvice(basePackageClasses = ProductController.class)
@Slf4j
public class GlobalExceptionHandle {
    /**
     * 自定义异常处理器
     *
     * @param response 响应对象
     * @return ResponseInfo
     */
    @ExceptionHandler({RuntimeException.class})
    public Result runtimeExceptionHandler(RuntimeException e, HttpServletResponse response) {
        // 设置响应对象
        Result resultResponse = new Result();
        if (e instanceof SystemBusyException) {
            resultResponse.setError(ResultEnum.YYSJ_SYSTEM_BUSY);
            response.setStatus(ResultEnum.YYSJ_SYSTEM_BUSY.getStatus());
        } else if (e instanceof TokenIsEmptyException) {
            resultResponse.setError(ResultEnum.YYSJ_REQUEST_TOKEN_PARAMETER_ERROR);
            response.setStatus(ResultEnum.YYSJ_REQUEST_TOKEN_PARAMETER_ERROR.getStatus());
        } else if (e instanceof ParamaterException) {
            resultResponse.setError(ResultEnum.YYSJ_REQUEST_PARAMETER_ERROR);
            response.setStatus(ResultEnum.YYSJ_REQUEST_PARAMETER_ERROR.getStatus());
        } else {
            resultResponse.setError(ResultEnum.YYSJ_SYSTEM_ERROR);
            response.setStatus(ResultEnum.YYSJ_SYSTEM_ERROR.getStatus());
        }
        log.error("", e);
        return resultResponse;
    }

}
