package info.aspirecn.cloud.yysj.cloudyysjagency.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import info.aspirecn.cloud.yysj.cloudyysjagency.entity.request.GetTokenRequest;
import info.aspirecn.cloud.yysj.cloudyysjagency.entity.request.remote.*;
import info.aspirecn.cloud.yysj.cloudyysjagency.service.YysjAgencyService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.*;
import org.springframework.stereotype.Service;
import org.springframework.web.client.HttpClientErrorException;
import org.springframework.web.client.RestTemplate;
import javax.servlet.http.HttpServletResponse;

@Service
public class YysjAgencyServiceImpl implements YysjAgencyService {

    @Autowired
    private RestTemplate restTemplate;

    @Value("${yysj.host}")
    private String host;

    @Value("${yysj.url.authentication}")
    private String authentication;

    @Value("${yysj.url.carQuery}")
    private String carQuery;

    @Value("${yysj.url.costQuery}")
    private String costQuery;

    @Value("${yysj.url.waybillQuery}")
    private String waybillQuery;


    @Value("${yysj.url.eidQuery}")
    private String eidQuery;

    @Value("${yysj.url.driverQuery}")
    private String driverQuery;

    @Value("${yysj.url.analysisQuery}")
    private String analysisQuery;

    @Value("${yysj.url.productConfig}")
    private String productConfig;

    @Value("${yysj.url.orderQuery}")
    private String orderQuery;

    /**
     * 登录
     * @return Object
     */
    @Override
    public Object login(GetTokenRequest getTokenRequest, HttpServletResponse response) {
        String url = host + authentication + "/login";
        Object object;
        try {
            object = restTemplate.postForObject(url, getTokenRequest, JSONObject.class);
        } catch (HttpClientErrorException e) {
            response.setStatus(e.getStatusCode().value());
            object = JSONObject.parseObject(e.getResponseBodyAsString());

        }
        return object;
    }

    /**
     * 车辆查询
     *
     * @return Object
     */
    @Override
    public Object queryCarList(CarQueryParam carQueryParam, String token, HttpServletResponse response) {
        String url = host + carQuery + "/querycar";
        return postForObject(url,carQueryParam,token,response);
    }

    /**
     * 车辆详情信息查询
     * @return Object
     */
    @Override
    public Object queryCarInfo(String carId, String token, HttpServletResponse response) {
        String url = host + carQuery + "/querycarinfo/" + carId;
        return getForObject(url,token,response);


    }

    /**
     * 充值记录接口实现逻辑
     * @return Object
     */
    @Override
    public Object queryRechargeInfoList(QueryParam queryParam, String token, HttpServletResponse response) {
        String url = host + costQuery +"/queryrecharge";
        return postForObject(url,queryParam,token,response);
    }

    /**
     * 调账单明细管理
     * @return Object
     */
    @Override
    public Object queryBillList(HttpServletResponse response, QueryParam queryParam, String token) {
        String url = host + costQuery +"/querybill";
        return postForObject(url,queryParam,token,response);
    }

    /**
     * 调运单列表接口
     * @return Object
     */
    @Override
    public Object queryWaybillList(HttpServletResponse response, WaybillQueryParam waybillQueryParam, String token) {
        String url = host + waybillQuery + "/querywaybill";
        Object object;
        HttpHeaders requestHeader = new HttpHeaders();
        requestHeader.setContentType(MediaType.parseMediaType("application/json;charset=UTF-8"));
        requestHeader.add("token", token);
        String para = JSON.toJSONString(waybillQueryParam);
        HttpEntity<String> requestEntity = new HttpEntity<>(para, requestHeader);
        try {
            object = restTemplate.postForEntity(url, requestEntity, JSONObject.class);
        } catch (HttpClientErrorException e) {
            response.setStatus(e.getStatusCode().value());
            object = JSONObject.parseObject(e.getResponseBodyAsString());
        }
        return object;
    }

    /**
     * 调运单详情
     * @return Object
     */

    @Override
    public Object querywaybillinfo(String waybillId, String token, HttpServletResponse response) {
        String url =host + waybillQuery + "/querywaybillinfo/"+waybillId;

        return getForObject(url,token,response);
    }

    /**
     * 查询司机校验信息列表接口
     * @return Object
     */
    @Override
    public Object getDriverList(DriverInfoRequest driverInfoRequest, String token, HttpServletResponse response) {
        String url = host + driverQuery + "/getDriverList";
        return postForObject(url,driverInfoRequest,token,response);
    }

    /**
     * 查询司机详情信息接口
     * @return  Object
     */
    @Override
    public Object getDriverDetails(DriverDetailsRequest driverDetailsRequest,
                                   String token,
                                   HttpServletResponse response) {
        String url = host + driverQuery + "/getDriverDetails";

        return postForObject(url,driverDetailsRequest,token,response);
    }

    /**
     * 账户信息
     * @return Object
     */
    @Override
    public Object getAccountInfo(String token,HttpServletResponse response) {
        String url = host + analysisQuery + "/accountInfo";
        return getForObject(url,token,response);
    }

    /**
     *  产品消费信息接口
     * @return Object
     */
    @Override
    public Object getConsumptionInfo(String token, HttpServletResponse response) {
        String url = host + analysisQuery + "/consumptionInfo";
        return getForObject(url,token,response);
    }

    /**
     * 主订单统计信息
     * @return Object
     */
    @Override
    public Object getOrderStatistics(String token, HttpServletResponse response) {
        String url = host + analysisQuery + "/statisticsInfo";
        return getForObject(url,token,response);
    }

    /**
     * 总订单统计信息
     * @param startTime 开始日期
     * @param endTime 结束日期
     * @return Object
     */
    @Override
    public Object getCountStatistics(String startTime, String endTime, String token, HttpServletResponse response) {
        String url = host + analysisQuery + "/countStatisticsInfo?startTime="+startTime+"&endTime="+endTime;
        return getForObject(url,token,response);
    }

    @Override
    public Object getErrorStatistics(String startTime, String endTime, String token, HttpServletResponse response) {
        String url = host + analysisQuery + "/exceptionStatisticsInfo?startTime="+startTime+"&endTime="+endTime;
        return getForObject(url,token,response);
    }

    /**
     * 新建产品接口
     * @return Object
     */
    @Override
    public Object saveProduce(Produce produce, String token, HttpServletResponse response) {
        String url = host + productConfig + "/saveProduce";

        return postForObject(url,produce,token,response);
    }

    /**
     * 查询产品列表
     * @return Object
     */
    @Override
    public Object productList(ProduceList produceList, String token, HttpServletResponse response) {
        String url = host + productConfig + "/productList";
        return postForObject(url,produceList,token,response);
    }

 /**
     * 查询产品名称列表
     * @return Object
     */
    @Override
    public Object getProductNameList(String token, HttpServletResponse response) {
        String url = host + productConfig + "/getProductNameList";
        return getForObject(url,token,response);
    }


    /**
     * 取消产品订购接口
     */
    @Override
    public Object deleteUserProduce(Integer produceId, String produceName, String token, HttpServletResponse response) {
        Object object;
        HttpHeaders requestHeader = new HttpHeaders();
        requestHeader.add("token", token);
        HttpEntity<String> requestEntity = new HttpEntity<>(requestHeader);
        String url = host + productConfig + "/deleteUserProduce?produceId="+produceId+"&produceName="+produceName;
        try {
            object= restTemplate.exchange(url, HttpMethod.DELETE, requestEntity,Object.class, Object.class);
        } catch (HttpClientErrorException e) {
            response.setStatus(e.getStatusCode().value());
            object = JSONObject.parseObject(e.getResponseBodyAsString());
        }
        return object;
    }

    /**
     * 订购产品接口
     * @return Object
     */
    @Override
    public Object saveUserProduce(UserProduce userProduce, String token, HttpServletResponse response) {
        String url = host + productConfig + "/saveUserProduce";
        return postForObject(url,userProduce,token,response);
    }


    /**
     * 获取订购产品数量
     */
    @Override
    public Object getOrderProductCount(String token, HttpServletResponse response) {
        String url = host + productConfig + "/getOrderProductCount";

        return getForObject(url,token,response);
    }

    @Override
    public Object logout(String token, HttpServletResponse response) {
        String url = host + authentication + "/logout";
        return getForObject(url,token,response);
    }

    /**
     * 订单
     * @param orderId
     * @param startTime
     * @param endTime
     * @param pageNum
     * @param pageSize
     * @param token
     * @param response
     * @return
     */
    @Override
    public Object getOrderList(String orderId, String startTime, String endTime, Integer pageNum, Integer pageSize, String token, HttpServletResponse response) {
        String url = host + orderQuery + "/orderList?orderId="+orderId+"&startTime="+startTime+"&endTime="+endTime+"&pageNum="+pageNum+"&pageSize="+pageSize;
        return getForObject(url,token,response);
    }

    /**
     * 订单详情
     * @param orderId
     * @param token
     * @param response
     * @return
     */
    @Override
    public Object getOrderDetail(String orderId, String token, HttpServletResponse response) {
        String url = host + orderQuery + "/order/"+orderId;
        return getForObject(url,token,response);
    }


    /**
     * restTemplate post 接口
     * @param url 请求url
     * @param parama 请求参数
     * @param token 请求token
     * @param response 响应体
     * @return Object
     */
    private Object postForObject(String url,Object parama,String token,HttpServletResponse response){
        Object object;
        HttpHeaders requestHeader = new HttpHeaders();
        requestHeader.setContentType(MediaType.parseMediaType("application/json;charset=UTF-8"));
        requestHeader.add("token", token);
        String para = JSON.toJSONString(parama);
        HttpEntity<String> requestEntity = new HttpEntity<>(para, requestHeader);
        try {
            object = restTemplate.postForEntity(url, requestEntity, JSONObject.class);
        } catch (HttpClientErrorException e) {
            response.setStatus(e.getStatusCode().value());
            object = JSONObject.parseObject(e.getResponseBodyAsString());
        }
        return object;
    }

    /**
     *  restTemplate get请求
     * @param url 请求url
     * @param token 请求头token
     * @param response  response
     * @return Object
     */
    private Object getForObject(String url,String token,HttpServletResponse response){
        Object object;
        HttpHeaders requestHeader = new HttpHeaders();
        requestHeader.add("token", token);
        HttpEntity<String> requestEntity = new HttpEntity<>(requestHeader);
        try {
            object = restTemplate.exchange(url, HttpMethod.GET, requestEntity, Object.class);
        } catch (HttpClientErrorException e) {
            response.setStatus(e.getStatusCode().value());
            object = JSONObject.parseObject(e.getResponseBodyAsString());


        }
        return object;
    }



    /**
     * 活体列表接口
     * @return Object
     */
    @Override
    public Object queryIdentityList(IdentityQueryParam identityQueryParam, String token, HttpServletResponse response) {
        String url = host + eidQuery + "/getIdentityList";
        Object object;
        HttpHeaders requestHeader = new HttpHeaders();
        requestHeader.setContentType(MediaType.parseMediaType("application/json;charset=UTF-8"));
        requestHeader.add("token", token);
        String para = JSON.toJSONString(identityQueryParam);
        HttpEntity<String> requestEntity = new HttpEntity<>(para, requestHeader);
        try {
            object = restTemplate.postForEntity(url, requestEntity, JSONObject.class);
        } catch (HttpClientErrorException e) {
            response.setStatus(e.getStatusCode().value());
            object = JSONObject.parseObject(e.getResponseBodyAsString());
        }
        return object;
    }



    /**
     * 活体列表接口
     * @return Object
     */
    @Override
    public Object queryLivingList(LivingQueryParam livingQueryParam, String token, HttpServletResponse response) {
        String url = host + eidQuery + "/getLivingList";
        Object object;
        HttpHeaders requestHeader = new HttpHeaders();
        requestHeader.setContentType(MediaType.parseMediaType("application/json;charset=UTF-8"));
        requestHeader.add("token", token);
        String para = JSON.toJSONString(livingQueryParam);
        HttpEntity<String> requestEntity = new HttpEntity<>(para, requestHeader);
        try {
            object = restTemplate.postForEntity(url, requestEntity, JSONObject.class);
        } catch (HttpClientErrorException e) {
            response.setStatus(e.getStatusCode().value());
            object = JSONObject.parseObject(e.getResponseBodyAsString());
        }
        return object;
    }

}
